@@ -2,7 +2,7 @@ package Dancer2::Plugin::Auth::OAuth;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Dancer2;
 use Dancer2::Plugin;
@@ -87,8 +87,9 @@ you do with it afterwards is up to you.
 
 =head1 CONFIGURATION
 
-The plugin comes with support for Facebook, Google and Twitter (other
-providers aren't hard to add, send me a pull request when you add more!)
+The plugin comes with support for Facebook, Google, Twitter, GitHub and Stack
+Exchange (other providers aren't hard to add, send me a pull request when you
+add more!)
 
 All it takes to use OAuth authentication for a given provider, is to add
 the configuration for it.
@@ -113,6 +114,16 @@ The YAML below shows all available options.
           tokens:
             consumer_key: your_consumer_token
             consumer_secret: your_consumer_secret
+         Github:
+           tokens:
+             client_id: your_client_id
+             client_secret: your_client_secret
+         Stackexchange:
+           tokens:
+             client_id: your_client_id
+             client_secret: your_client_secret
+             key: your_key
+           site: stackoverflow
 
 [*] default value, may be omitted.
 
